"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.texSyntax = void 0;
const syntax_1 = require("@codemirror/next/syntax");
const lezer_tex_1 = require("lezer-tex");
const highlight_1 = require("./highlight");
const defaultTags = {
    // Specific tokens
    "{ }": "brace",
    "[ ]": "squareBracket",
    "ReservedCharacter": "operator",
    "Parameter": "variableName",
    "Comment": "comment",
    // Control sequence
    "ControlSequenceName": "variableName definition",
    // Control sequences
    "ControlWord": "atom",
    "ControlSpace": "separator",
    "ControlLine": "keyword",
    // Environment
    "BeginEnvironment EndEnvironment EnvEndCommand": "atom",
    "MismatchedEnvEndCommand": "atom invalid",
    "EnvironmentName": "namespace",
    // Verbatim
    "VerbContent VerbatimContent": "docString monospace",
    // Commands
    "CommandName": "atom",
    // Text formatting commands
    "textmd": "+semistrong",
    "textbf": "+strong",
    "textit textsl": "+emphasis",
    "textup": "+noemphasis",
    "texttt": "+monospace",
    "textnormal": "+normal",
    "textsc": "+smallcap",
    "underline": "+underline",
    // Math formatting commands
    "mathbf/Argument": "strong",
    "mathit/Argument": "emphasis",
    "mathtt/Argument": "monospace",
    "MathBlock MathLine": "string",
    // Math block
    "MathContent": "string emphasis",
};
const specializedTags = {
    // Text formatting commands
    textmd: "+semistrong",
    textup: "+noemphasis",
    textnormal: "+normal",
    textsc: "+smallcap",
    underline: "+underline",
};
/// A syntax provider based on the Lezer TeX parser, extended with
/// highlighting and indentation information.
function texSyntax(option) {
    const tagPropSource = option && option.tagSystem
        ? option.tagSystem.add(defaultTags)
        : highlight_1.TeXTagSystem.add(Object.assign(defaultTags, specializedTags));
    const foldPropSource = syntax_1.foldNodeProp.add({
        MathBlock(tree) {
            return { from: tree.start + 2, to: tree.end - 2 };
        },
        Environment(tree) {
            return {
                from: tree.firstChild?.firstChild?.end,
                to: tree.lastChild?.lastChild?.start,
            };
        },
    });
    const indentPropSource = syntax_1.indentNodeProp.add((type) => {
        if (type.name === "MathBlock")
            return syntax_1.delimitedIndent({ closing: "$$", align: false });
        return undefined;
    });
    const languageData = {
        closeBrackets: {
            brackets: ["(", "[", "{"],
            before: ")]}",
        },
        commentTokens: { line: "%" },
    };
    return syntax_1.LezerSyntax.define(lezer_tex_1.parser.withProps(indentPropSource, foldPropSource, tagPropSource), {
        languageData,
    });
}
exports.texSyntax = texSyntax;
